@@ -249,10 +249,7 @@ def _predict_batch_cpu(output_dir, input_path, n_cores=-1, roi_bins=list(range(0
     aggregate_and_post_process(output_path_parcellation, output_path_brainmask, output_path_stat, pred_y, whole_brain, input_affine)
 
 def load_prediction_model(mode="cpu"):
-    if "cpu" == mode:
-        from tensorflow.keras.models import model_from_json
-    else:
-        from keras.models import model_from_json
+    from tensorflow.keras.models import model_from_json
     parent_dir = os.path.dirname(os.path.abspath(__file__))
     with open(f"{parent_dir}/Attention3DUNet.json", "r") as json_file:
         model = model_from_json(json_file.read())
